#[non_exhaustive]pub enum Error {
Show 31 variants
EmptyEndpoints,
Io(Error),
Semver(Error),
Serialization(Error),
ReleaseNotFound,
UnsupportedArch,
UnsupportedOs,
FailedToDetermineExtractPath,
UrlParse(ParseError),
Reqwest(Error),
TargetNotFound(String),
TargetsNotFound(Vec<String>),
Network(String),
Minisign(Error),
Base64(DecodeError),
SignatureUtf8(String),
TempDirNotOnSameMountPoint,
BinaryNotFoundInArchive,
TempDirNotFound,
AuthenticationFailed,
DebInstallFailed,
PackageInstallFailed,
InvalidUpdaterFormat,
Http(Error),
InvalidHeaderValue(InvalidHeaderValue),
InvalidHeaderName(InvalidHeaderName),
FormatDate,
InsecureTransportProtocol,
SignedVersionMismatch {
signed: String,
announced: String,
},
MissingSignedVersion,
Tauri(Error),
}Expand description
All errors that can occur while running the updater.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EmptyEndpoints
Endpoints are not sent.
Io(Error)
IO errors.
Semver(Error)
Semver errors.
Serialization(Error)
Serialization errors.
ReleaseNotFound
Could not fetch a valid response from the server.
UnsupportedArch
Unsupported app architecture.
UnsupportedOs
Operating system is not supported.
FailedToDetermineExtractPath
Failed to determine updater package extract path
UrlParse(ParseError)
Url parsing errors.
Reqwest(Error)
reqwest crate errors.
TargetNotFound(String)
The platform was not found in the updater JSON response.
TargetsNotFound(Vec<String>)
Neither the platform nor the fallback platform was found in the updater JSON response.
Network(String)
Download failed
Minisign(Error)
minisign_verify errors.
Base64(DecodeError)
base64 errors.
SignatureUtf8(String)
UTF8 Errors in signature.
TempDirNotOnSameMountPoint
Temp dir is not on same mount mount. This prevents our updater to rename the AppImage to a temp file.
BinaryNotFoundInArchive
TempDirNotFound
AuthenticationFailed
DebInstallFailed
PackageInstallFailed
InvalidUpdaterFormat
Http(Error)
InvalidHeaderValue(InvalidHeaderValue)
InvalidHeaderName(InvalidHeaderName)
FormatDate
InsecureTransportProtocol
The configured updater endpoint must use a secure protocol like https
SignedVersionMismatch
The version the artifact was signed for does not match the version announced by the update endpoint.
Fields
MissingSignedVersion
requireSignedVersion is enabled but the signature does not carry a version.
Tauri(Error)